@@ -1,15 +1,16 @@
-/* archimedes.c -- This code is a simulator for Submicron 2D Silicon/GaAs
-   Devices. It implements the Monte Carlo method and a simplified
-   version of MEP model for the simulation of the semiclassical
-   Boltzmann equation for both electrons and holes.
+/* archimedes.c -- This code is a simulator for Submicron 2D III-V
+   semiconductor Devices (along with SiO2). It implements the Monte Carlo method 
+   and a  simplified version of MEP model for the simulation of the 
+   semiclassical Boltzmann equation for both electrons and holes.
    It also includes the quantum effects by means of effective
-   potential method.
+   potential method. It is now able to simulate applied
+   magnetic fields along with self consistent Faraday equation.
 
-   Copyright (C) 2004, 2005 Jean Michel Sellier <sellier@dmi.unict.it>
+   Copyright (C) 2004, 2005, 2006, 2007 Jean Michel Sellier <sellier@dmi.unict.it>
  
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -25,9 +26,9 @@
 
 // =================================================================
 // File Name : mainArchimedes.c
-// Version   : release 0.0.5
+// Version   : release 0.0.8
 // Date of Creation : 07 Dec.2003, Paris, France, Jean Michel Sellier
-// Last Revision : 07 Apr.2005, Siracusa, Italy, Jean Michel Sellier.
+// Last Revision : 18 August 2007, Siracusa, Italy, Jean Michel Sellier.
 // System of Measure : M.K.S.C. System
 // =================================================================
 
@@ -48,8 +49,8 @@
 // Preprocessor Definitions
 #define real double
 #define MN3 4
-#define NXM 308
-#define NYM 308
+#define NXM 158
+#define NYM 158
 #define DIME 2003
 #define ITMAX 10000000
 #define POISSONITMAX 1500
@@ -66,6 +67,7 @@
 #define MESHFORMAT 1 // output file in Mesh format
 #define SILICON 0 // flag for Silicon material
 #define GAAS 1 // flag for GaAs material
+#define GERMANIUM 2 // flag for Germanium material
 #define NUMSIO2 2 // maximum number of SiO2 interfaces
 
 // ===============================
@@ -86,6 +88,7 @@ int c,Model_Number,File_Format,Material,Quantum_Flag;
 int leid_flag;
 int SIO2_UP_FLAG;
 int SIO2_DOWN_FLAG;
+int FARADAYFLAG;
 
 // All "real"'s here...
 real u2d[NXM+1][NYM+1][MN3+1];
@@ -121,6 +124,7 @@ real SIO2_INI[NUMSIO2],SIO2_FIN[NUMSIO2];
 real SIO2_POT[NUMSIO2];
 real SIO2_THICKNESS[NUMSIO2];
 real SIO2[NUMSIO2][NXM+1][NYM+1];
+real B[NXM+1][NYM+1];
 
 // All structures here...
 time_t binarytime;
@@ -205,7 +209,7 @@ Report bugs to sellier@dmi.unict.it\n");
   if (v)
     {
       /* Print version number.  */
-      printf("archimedes - GNU archimedes 0.0.5\n");
+      printf("archimedes - GNU archimedes 0.0.8\n");
       /* xgettext: no-wrap */
       printf("\n");
       printf("\
@@ -257,6 +261,7 @@ For more information about these matters, see the file named COPYING.\n",
 // Boundary conditions for the model simulated
 // ===========================================
      PoissonBCs();
+     if(FARADAYFLAG) FaradayBCs();
 
 // Initialisation for Monte Carlo
 // ==============================
@@ -282,6 +287,7 @@ For more information about these matters, see the file named COPYING.\n",
    binarytime=time(NULL);
    nowtm=localtime(&binarytime);
    printf("Computation Finished at %s\n",asctime(nowtm));
+   system("PAUSE");
    return(EXIT_SUCCESS); // Successfull exit
 }
 
@@ -290,9 +296,10 @@ For more information about these matters, see the file named COPYING.\n",
 // ****************************************************
 
 // =======================================================
-// Modif. 06 ago.2004 - 04 Mar.2005, Siracusa, J.M.Sellier
+// Modif. 06 ago.2004 - 18 Aug.2007, Siracusa, J.M.Sellier
 // =======================================================
 #include "poissonbcs.h"
+#include "faradaybcs.h"
 #include "media.h"
 #include "saveoutput2dmeshformat.h"
 #include "saveoutput2dgnuplot.h"
@@ -300,6 +307,7 @@ For more information about these matters, see the file named COPYING.\n",
 #include "saveoutput2dholemeshformat.h"
 #include "saveoutputfiles.h"
 #include "electric_field.h"
+#include "faraday.h"
 #include "quantumeffectivepotential.h"
 #include "random.h"
 #include "mcparameters.h"
